==> ejc-supbid-api-3.0.1-20211214.064606-48-sources.jar: com/ejianc/business/supbid/notice/vo/SupOfferVO.java <==
package com.ejianc.business.supbid.notice.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 报名实体
 * 
 * @author generator
 * 
 */
@ApiModel("报名实体")
public class SupOfferVO {
    private static final long serialVersionUID = 1L;

    @ApiModelProperty("招标信息主键")
    private String sourceId;
    @ApiModelProperty("洽商轮数")
    private Integer talkNum;
    @ApiModelProperty("租户主键")
    private Long tenantId;
    @ApiModelProperty("淘汰原因")
    private String outReason;
    @ApiModelProperty("类型1-流标，2-废标")
    private Integer type;

    public String getOutReason() {
        return outReason;
    }

    public void setOutReason(String outReason) {
        this.outReason = outReason;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public Integer getTalkNum() {
        return talkNum;
    }

    public void setTalkNum(Integer talkNum) {
        this.talkNum = talkNum;
    }

    public Long getTenantId() {
        return tenantId;
    }

    public void setTenantId(Long tenantId) {
        this.tenantId = tenantId;
    }
}

==> ejc-supbid-api-3.0.1-20251028.021232-295-sources.jar: com/ejianc/business/supbid/notice/vo/SupOfferVO.java <==
package com.ejianc.business.supbid.notice.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 报名实体
 * 
 * @author generator
 * 
 */
@ApiModel("报名实体")
public class SupOfferVO {
    private static final long serialVersionUID = 1L;

    @ApiModelProperty("招标信息主键")
    private String sourceId;
    @ApiModelProperty("洽商轮数")
    private Integer talkNum;
    @ApiModelProperty("租户主键")
    private Long tenantId;
    @ApiModelProperty("淘汰原因")
    private String outReason;
    @ApiModelProperty("类型1-流标，2-废标")
    private Integer type;
    private String sourceSupplierId; // 供应商主键
    private Integer signStatus; //
    private Integer repetitionFlag; //是否二次报价, 0-否,1-是

    public String getSourceSupplierId() {
        return sourceSupplierId;
    }

    public void setSourceSupplierId(String sourceSupplierId) {
        this.sourceSupplierId = sourceSupplierId;
    }

    public Integer getSignStatus() {
        return signStatus;
    }

    public void setSignStatus(Integer signStatus) {
        this.signStatus = signStatus;
    }

    public Integer getRepetitionFlag() {
        return repetitionFlag;
    }

    public void setRepetitionFlag(Integer repetitionFlag) {
        this.repetitionFlag = repetitionFlag;
    }

    public String getOutReason() {
        return outReason;
    }

    public void setOutReason(String outReason) {
        this.outReason = outReason;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public Integer getTalkNum() {
        return talkNum;
    }

    public void setTalkNum(Integer talkNum) {
        this.talkNum = talkNum;
    }

    public Long getTenantId() {
        return tenantId;
    }

    public void setTenantId(Long tenantId) {
        this.tenantId = tenantId;
    }
}
